import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/all_devices/models/factory_reset_model.dart';
import 'package:syncrow_web/pages/device_managment/door_lock/bloc/door_lock_bloc.dart';
import 'package:syncrow_web/pages/device_managment/door_lock/bloc/door_lock_event.dart';
import 'package:syncrow_web/pages/device_managment/shared/batch_control/factory_reset.dart';
import 'package:syncrow_web/pages/device_managment/shared/batch_control/firmware_update.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

class DoorLockBatchControlView extends StatelessWidget
    with HelperResponsiveLayout {
  const DoorLockBatchControlView({super.key, required this.devicesIds});

  final List<String> devicesIds;

  @override
  Widget build(BuildContext context) {
    final isExtraLarge = isExtraLargeScreenSize(context);
    final isLarge = isLargeScreenSize(context);
    final isMedium = isMediumScreenSize(context);
    return SizedBox(
      child: GridView(
        padding: const EdgeInsets.symmetric(horizontal: 50, vertical: 20),
        shrinkWrap: true,
        physics: const NeverScrollableScrollPhysics(),
        gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: isLarge || isExtraLarge || isMedium ? 2 : 1,
          mainAxisExtent: 140,
          crossAxisSpacing: 12,
          mainAxisSpacing: 12,
        ),
        children: [
          FirmwareUpdateWidget(
            deviceId: devicesIds.first,
            version: 12,
          ),
          FactoryResetWidget(
            callFactoryReset: () {
              BlocProvider.of<DoorLockBloc>(context).add(
                DoorLockFactoryReset(
                  deviceId: devicesIds.first,
                  factoryReset: FactoryResetModel(devicesUuid: devicesIds),
                ),
              );
            },
          ),
        ],
      ),
    );
  }
}
